==> cdktf_cdktf_provider_azurerm-0.6.19-py3-none-any.whl: package/lib/data-azurerm-web-pubsub.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermWebPubsubConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub#name DataAzurermWebPubsub#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub#resource_group_name DataAzurermWebPubsub#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub#timeouts DataAzurermWebPubsub#timeouts}
    */
    readonly timeouts?: DataAzurermWebPubsubTimeouts;
}
export interface DataAzurermWebPubsubTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub#read DataAzurermWebPubsub#read}
    */
    readonly read?: string;
}
export declare function dataAzurermWebPubsubTimeoutsToTerraform(struct?: DataAzurermWebPubsubTimeoutsOutputReference | DataAzurermWebPubsubTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermWebPubsubTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermWebPubsubTimeouts | undefined;
    set internalValue(value: DataAzurermWebPubsubTimeouts | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub azurerm_web_pubsub}
*/
export declare class DataAzurermWebPubsub extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_web_pubsub";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub azurerm_web_pubsub} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermWebPubsubConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermWebPubsubConfig);
    get aadAuthEnabled(): cdktf.IResolvable;
    get capacity(): number;
    get externalIp(): string;
    get hostname(): string;
    get id(): string;
    get localAuthEnabled(): cdktf.IResolvable;
    get location(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get primaryAccessKey(): string;
    get primaryConnectionString(): string;
    get publicNetworkAccessEnabled(): cdktf.IResolvable;
    get publicPort(): number;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    get secondaryAccessKey(): string;
    get secondaryConnectionString(): string;
    get serverPort(): number;
    get sku(): string;
    tags(key: string): string | cdktf.IResolvable;
    get tlsClientCertEnabled(): cdktf.IResolvable;
    get version(): string;
    private _timeouts;
    get timeouts(): DataAzurermWebPubsubTimeoutsOutputReference;
    putTimeouts(value: DataAzurermWebPubsubTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): DataAzurermWebPubsubTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf_cdktf_provider_azurerm-1.0.3-py3-none-any.whl: package/lib/data-azurerm-web-pubsub.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataAzurermWebPubsubConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub#id DataAzurermWebPubsub#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub#name DataAzurermWebPubsub#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub#resource_group_name DataAzurermWebPubsub#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub#timeouts DataAzurermWebPubsub#timeouts}
    */
    readonly timeouts?: DataAzurermWebPubsubTimeouts;
}
export interface DataAzurermWebPubsubTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub#read DataAzurermWebPubsub#read}
    */
    readonly read?: string;
}
export declare function dataAzurermWebPubsubTimeoutsToTerraform(struct?: DataAzurermWebPubsubTimeoutsOutputReference | DataAzurermWebPubsubTimeouts | cdktf.IResolvable): any;
export declare class DataAzurermWebPubsubTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): DataAzurermWebPubsubTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: DataAzurermWebPubsubTimeouts | cdktf.IResolvable | undefined);
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub azurerm_web_pubsub}
*/
export declare class DataAzurermWebPubsub extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "azurerm_web_pubsub";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/azurerm/d/web_pubsub azurerm_web_pubsub} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataAzurermWebPubsubConfig
    */
    constructor(scope: Construct, id: string, config: DataAzurermWebPubsubConfig);
    get aadAuthEnabled(): cdktf.IResolvable;
    get capacity(): number;
    get externalIp(): string;
    get hostname(): string;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    get localAuthEnabled(): cdktf.IResolvable;
    get location(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    get primaryAccessKey(): string;
    get primaryConnectionString(): string;
    get publicNetworkAccessEnabled(): cdktf.IResolvable;
    get publicPort(): number;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    get secondaryAccessKey(): string;
    get secondaryConnectionString(): string;
    get serverPort(): number;
    get sku(): string;
    private _tags;
    get tags(): cdktf.StringMap;
    get tlsClientCertEnabled(): cdktf.IResolvable;
    get version(): string;
    private _timeouts;
    get timeouts(): DataAzurermWebPubsubTimeoutsOutputReference;
    putTimeouts(value: DataAzurermWebPubsubTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | DataAzurermWebPubsubTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
